Free Proxy Servers Since 2002
Share:

# Add a New Proxy

Submit a proxy to be included in the database.
No link back is required but we would appreciate it.
The proxy should be running on a dedicated domain name.

Add a New Proxy
URL * |
Name |
Description |
Owner E-mail |
Add Record

## Rules

No blocking/redirecting/etc by country.
No interstitial ads.
No pop-ups of any kind.
No full page ads.
No audio ads.
URL field on the main page
- should be visible without scrolling;
- should be easy to locate;
- should come with a submit button like "Go", "Surf", etc.
Top header (ads with proxy controls elements) on proxied pages should be no more than 25% of an average screen in height.
Proxy software
- no anti-robot or whatever javascript encryption of main pages.

## Q&A About Our Rules

Why country blocking is prohibited?
Because proxy means freedom, please don't ruin the idea.

Why ad restrictions?
We think that all those full of shit blasting with endless popups sites kill the entire proxy business like nothing else. Besides that we want our visitors to return. So we'll be able to send you more traffic. All happy.

Why no encrypted pages or custom scripts?
Because it's impossible to automatically check such proxy servers.